==> libstpk-0.9.19.0.tar.gz: libstpk-0.9.19.0/demo/unit/matrix_test.f90 <==
program matrix_test
  use Matrix_Calc
  implicit none
  integer, parameter :: nx=3
  real, dimension(nx) :: x, z
  real, dimension(nx,nx) :: a, b
  integer :: i, j, k
  real :: eps, accel, val

  write(*,*) "input the method."
  write(*,*) "[1]=gauss, [2]=LU, [3]=Gau_sei, [4]=Jacobi,"
  write(*,*) "[5]=SOR_Gau, [6]=SOR_Jacobi, [7]=invert, [8]=eigenvalue."
  write(*,*) "[9]=Jacobi engen, [10]=QR eigen."
  read(*,*) k

  if(k==9.or.k==8.or.k==10)then  ! 9 ֤, eigen.dat 򳫤.
     open(unit=10,file='eigen.dat',status='old')
  else
     open(unit=10,file='data.dat',status='old')
  end if
     do j=1,nx
        read(10,*) (a(i,j),i=1,nx), z(j)
     end do
  close(unit=10,status='keep')

  write(*,*) "output reading array"
  do i=1,nx
     write(*,*) (a(i,j),j=1,nx)
  end do

  eps=1.e-6
  accel=1.0

  select case(k)
  case(1)
     call gausss( a, z, x )
     do i=1,nx
        write(*,*) x(i)
     end do

  case(2)
     call LU_devs( a, z, x, 10 )
     do i=1,nx
        write(*,*) x(i)
     end do

  case(3)
     call Gau_Sei( a, z, eps, x )
     do i=1,nx
        write(*,*) x(i)
     end do

  case(4)
     call Jacobi_algebra( a, z, eps, x )
     do i=1,nx
        write(*,*) x(i)
     end do

  case(5)
     call SOR_Gau_Sei( a, z, eps, accel, x )
     do i=1,nx
        write(*,*) x(i)
     end do

  case(6)
     call SOR_Jacobi_algebra( a, z, eps, accel, x )
     do i=1,nx
        write(*,*) x(i)
     end do

  case(7)
     b=0.0
     call invert_mat( a, b )
     write(*,*) "answer is,"
     do i=1,nx
        write(*,*) (b(i,j),j=1,nx)
     end do

  case(8)
     b=0.0
     x=0.0
     call eigenvalue_power( a, eps, val, x )
     write(*,*) "eigenvalue is ", val
     write(*,*) "eigen vector is"
     do i=1,nx
        write(*,*) x(i)
     end do

  case(9)
     b=0.0
     x=0.0
     call Jacobi_eigen( a, x, eps )
     write(*,*) "eigenvalue is "
     do i=1,nx
        write(*,*) x(i)
     end do

  case(10)
     b=0.0
     x=0.0
     call QR_method( a, x, p=b, eps=eps, sym_opt=.true. )
     write(*,*) "eigenvalue is "
     do i=1,nx
        write(*,*) x(i)
     end do
     write(*,*) "eigenvector is"
     do i=1,nx
        write(*,*) "(", (b(i,j),j=1,nx), ")"
     end do

  end select

end program

==> libstpk-0.9.31.0.tar.gz: libstpk-0.9.31.0/demo/unit/matrix_test.f90 <==
program matrix_test
  use Matrix_Calc
  implicit none
  integer, parameter :: nx=3
  real, dimension(nx) :: x, z
  real, dimension(nx,nx) :: a, b
  integer :: i, j, k
  real :: eps, accel, val

  write(*,*) "input the method."
  write(*,*) "[1]=gauss, [2]=LU, [3]=Gau_sei, [4]=Jacobi,"
  write(*,*) "[5]=SOR_Gau, [6]=SOR_Jacobi, [7]=invert, [8]=eigenvalue."
  write(*,*) "[9]=Jacobi engen, [10]=QR eigen."
  read(*,*) k

  if(k==9.or.k==8.or.k==10)then  ! 9 番だけ, eigen.dat を開く.
     open(unit=10,file='eigen.dat',status='old')
  else
     open(unit=10,file='data.dat',status='old')
  end if
     do j=1,nx
        read(10,*) (a(i,j),i=1,nx), z(j)
     end do
  close(unit=10,status='keep')

  write(*,*) "output reading array"
  do i=1,nx
     write(*,*) (a(i,j),j=1,nx)
  end do

  eps=1.e-6
  accel=1.0

  select case(k)
  case(1)
     call gausss( a, z, x )
     do i=1,nx
        write(*,*) x(i)
     end do

  case(2)
     call LU_devs( a, z, x, 10 )
     do i=1,nx
        write(*,*) x(i)
     end do

  case(3)
     call Gau_Sei( a, z, eps, x )
     do i=1,nx
        write(*,*) x(i)
     end do

  case(4)
     call Jacobi_algebra( a, z, eps, x )
     do i=1,nx
        write(*,*) x(i)
     end do

  case(5)
     call SOR_Gau_Sei( a, z, eps, accel, x )
     do i=1,nx
        write(*,*) x(i)
     end do

  case(6)
     call SOR_Jacobi_algebra( a, z, eps, accel, x )
     do i=1,nx
        write(*,*) x(i)
     end do

  case(7)
     b=0.0
     call invert_mat( a, b )
     write(*,*) "answer is,"
     do i=1,nx
        write(*,*) (b(i,j),j=1,nx)
     end do

  case(8)
     b=0.0
     x=0.0
     call eigenvalue_power( a, eps, val, x )
     write(*,*) "eigenvalue is ", val
     write(*,*) "eigen vector is"
     do i=1,nx
        write(*,*) x(i)
     end do

  case(9)
     b=0.0
     x=0.0
     call Jacobi_eigen( a, x, eps )
     write(*,*) "eigenvalue is "
     do i=1,nx
        write(*,*) x(i)
     end do

  case(10)
     b=0.0
     x=0.0
     call QR_method( a, x, p=b, eps=eps, sym_opt=.true. )
     write(*,*) "eigenvalue is "
     do i=1,nx
        write(*,*) x(i)
     end do
     write(*,*) "eigenvector is"
     do i=1,nx
        write(*,*) "(", (b(i,j),j=1,nx), ")"
     end do

  end select

end program
